@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.120-9-g50af684
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.121-9-g1e8107f
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 
-our $VERSION = '0.121';
+our $VERSION = '0.122';
 
 use Moose;
 with
@@ -21,6 +21,7 @@ use Devel::CheckBin 'can_run';
 use Path::Tiny;
 use CPAN::Meta::Requirements;
 use Term::ANSIColor 'colored';
+eval 'require Win32::Console::ANSI' if $^O eq 'MSWin32';
 use namespace::autoclean;
 
 sub mvp_multivalue_args { qw(installer copy_file_from_release) }
@@ -117,6 +118,13 @@ has authority => (
     },
 );
 
+has fake_release => (
+    is => 'ro', isa => 'Bool',
+    init_arg => undef,
+    lazy => 1,
+    default => sub { $ENV{FAKE_RELEASE} || $_[0]->payload->{fake_release} // 0 },
+);
+
 # configs are applied when plugins match ->isa($key) or ->does($key)
 my %extra_args = (
     'Dist::Zilla::Plugin::MakeMaker' => { 'eumm_version' => '0' },
@@ -338,7 +346,9 @@ sub configure
         # (ConfirmRelease)
 
         # Releaser
-        'UploadToCPAN',
+        $self->fake_release
+            ? do { warn '[@Author::ETHER] ', colored('FAKE_RELEASE set - not uploading to CPAN', 'yellow'), "\n"; 'FakeRelease' }
+            : 'UploadToCPAN',
 
         # After Release
         ( $self->licence eq 'LICENSE' && -e 'LICENCE' ?
@@ -470,7 +480,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.121
+version 0.122
 
 =head1 SYNOPSIS
 
@@ -1013,6 +1023,14 @@ passed through to the <[Authority]|Dist::Zilla::Plugin::Authority> plugin, and f
 It is presently used for setting C<x_authority> metadata and deciding which spelling is used for the F<LICENCE>
 file (if the C<licence> configuration is not provided).
 
+=head2 fake_release
+
+Available since 0.122.
+
+A boolean option, that when set, removes <[UploadToCPAN]|Dist::Zilla::Plugin::UploadToCPAN> from the plugin list
+and replaces it with <[FakeRelease]|Dist::Zilla::Plugin::FakeRelease>.
+Defaults to false; can also be set with the environment variable C<FAKE_RELEASE>.
+
 =for stopwords customizations
 
 =head2 other customizations
@@ -1071,7 +1089,7 @@ Karen Etheridge <ether@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Dave Rolsky Graham Knop Randy Stauner Сергей Романов
+=for stopwords Dave Rolsky Graham Knop Randy Stauner Roy Ivy III Сергей Романов
 
 =over 4
 
@@ -1089,6 +1107,10 @@ Randy Stauner <rwstauner@cpan.org>
 
 =item *
 
+Roy Ivy III <rivy@cpan.org>
+
+=item *
+
 Сергей Романов <sromanov@cpan.org>
 
 =back
